==> ec2-1.0.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/ec2/CfnHostProps.java <==
package software.amazon.awscdk.services.ec2;

/**
 * Properties for defining a `AWS::EC2::Host`.
 * 
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-host.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.14.0 (build a586a1a)", date = "2019-07-11T14:13:21.581Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnHostProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * `AWS::EC2::Host.AvailabilityZone`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-host.html#cfn-ec2-host-availabilityzone
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getAvailabilityZone();
    /**
     * `AWS::EC2::Host.InstanceType`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-host.html#cfn-ec2-host-instancetype
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getInstanceType();
    /**
     * `AWS::EC2::Host.AutoPlacement`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-host.html#cfn-ec2-host-autoplacement
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getAutoPlacement();
    /**
     * `AWS::EC2::Host.HostRecovery`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-host.html#cfn-ec2-host-hostrecovery
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getHostRecovery();

    /**
     * @return a {@link Builder} of {@link CfnHostProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link CfnHostProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Builder {
        private java.lang.String _availabilityZone;
        private java.lang.String _instanceType;
        @javax.annotation.Nullable
        private java.lang.String _autoPlacement;
        @javax.annotation.Nullable
        private java.lang.String _hostRecovery;

        /**
         * Sets the value of AvailabilityZone
         * @param value `AWS::EC2::Host.AvailabilityZone`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder withAvailabilityZone(final java.lang.String value) {
            this._availabilityZone = java.util.Objects.requireNonNull(value, "availabilityZone is required");
            return this;
        }
        /**
         * Sets the value of InstanceType
         * @param value `AWS::EC2::Host.InstanceType`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder withInstanceType(final java.lang.String value) {
            this._instanceType = java.util.Objects.requireNonNull(value, "instanceType is required");
            return this;
        }
        /**
         * Sets the value of AutoPlacement
         * @param value `AWS::EC2::Host.AutoPlacement`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder withAutoPlacement(@javax.annotation.Nullable final java.lang.String value) {
            this._autoPlacement = value;
            return this;
        }
        /**
         * Sets the value of HostRecovery
         * @param value `AWS::EC2::Host.HostRecovery`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder withHostRecovery(@javax.annotation.Nullable final java.lang.String value) {
            this._hostRecovery = value;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnHostProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public CfnHostProps build() {
            return new CfnHostProps() {
                private final java.lang.String $availabilityZone = java.util.Objects.requireNonNull(_availabilityZone, "availabilityZone is required");
                private final java.lang.String $instanceType = java.util.Objects.requireNonNull(_instanceType, "instanceType is required");
                @javax.annotation.Nullable
                private final java.lang.String $autoPlacement = _autoPlacement;
                @javax.annotation.Nullable
                private final java.lang.String $hostRecovery = _hostRecovery;

                @Override
                public java.lang.String getAvailabilityZone() {
                    return this.$availabilityZone;
                }

                @Override
                public java.lang.String getInstanceType() {
                    return this.$instanceType;
                }

                @Override
                public java.lang.String getAutoPlacement() {
                    return this.$autoPlacement;
                }

                @Override
                public java.lang.String getHostRecovery() {
                    return this.$hostRecovery;
                }

                public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
                    com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
                    com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
                    obj.set("availabilityZone", om.valueToTree(this.getAvailabilityZone()));
                    obj.set("instanceType", om.valueToTree(this.getInstanceType()));
                    if (this.getAutoPlacement() != null) {
                        obj.set("autoPlacement", om.valueToTree(this.getAutoPlacement()));
                    }
                    if (this.getHostRecovery() != null) {
                        obj.set("hostRecovery", om.valueToTree(this.getHostRecovery()));
                    }
                    return obj;
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.ec2.CfnHostProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * `AWS::EC2::Host.AvailabilityZone`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-host.html#cfn-ec2-host-availabilityzone
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public java.lang.String getAvailabilityZone() {
            return this.jsiiGet("availabilityZone", java.lang.String.class);
        }

        /**
         * `AWS::EC2::Host.InstanceType`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-host.html#cfn-ec2-host-instancetype
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public java.lang.String getInstanceType() {
            return this.jsiiGet("instanceType", java.lang.String.class);
        }

        /**
         * `AWS::EC2::Host.AutoPlacement`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-host.html#cfn-ec2-host-autoplacement
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @javax.annotation.Nullable
        public java.lang.String getAutoPlacement() {
            return this.jsiiGet("autoPlacement", java.lang.String.class);
        }

        /**
         * `AWS::EC2::Host.HostRecovery`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-host.html#cfn-ec2-host-hostrecovery
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @javax.annotation.Nullable
        public java.lang.String getHostRecovery() {
            return this.jsiiGet("hostRecovery", java.lang.String.class);
        }
    }
}

==> ec2-1.1.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/ec2/CfnHostProps.java <==
package software.amazon.awscdk.services.ec2;

/**
 * Properties for defining a `AWS::EC2::Host`.
 * 
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-host.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.14.2 (build e881f16)", date = "2019-07-19T19:06:47.507Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
public interface CfnHostProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * `AWS::EC2::Host.AvailabilityZone`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-host.html#cfn-ec2-host-availabilityzone
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getAvailabilityZone();
    /**
     * `AWS::EC2::Host.InstanceType`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-host.html#cfn-ec2-host-instancetype
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getInstanceType();
    /**
     * `AWS::EC2::Host.AutoPlacement`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-host.html#cfn-ec2-host-autoplacement
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getAutoPlacement();
    /**
     * `AWS::EC2::Host.HostRecovery`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-host.html#cfn-ec2-host-hostrecovery
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getHostRecovery();

    /**
     * @return a {@link Builder} of {@link CfnHostProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link CfnHostProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    final class Builder {
        private java.lang.String _availabilityZone;
        private java.lang.String _instanceType;
        @javax.annotation.Nullable
        private java.lang.String _autoPlacement;
        @javax.annotation.Nullable
        private java.lang.String _hostRecovery;

        /**
         * Sets the value of AvailabilityZone
         * @param value `AWS::EC2::Host.AvailabilityZone`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder withAvailabilityZone(final java.lang.String value) {
            this._availabilityZone = java.util.Objects.requireNonNull(value, "availabilityZone is required");
            return this;
        }
        /**
         * Sets the value of InstanceType
         * @param value `AWS::EC2::Host.InstanceType`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder withInstanceType(final java.lang.String value) {
            this._instanceType = java.util.Objects.requireNonNull(value, "instanceType is required");
            return this;
        }
        /**
         * Sets the value of AutoPlacement
         * @param value `AWS::EC2::Host.AutoPlacement`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder withAutoPlacement(@javax.annotation.Nullable final java.lang.String value) {
            this._autoPlacement = value;
            return this;
        }
        /**
         * Sets the value of HostRecovery
         * @param value `AWS::EC2::Host.HostRecovery`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder withHostRecovery(@javax.annotation.Nullable final java.lang.String value) {
            this._hostRecovery = value;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnHostProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public CfnHostProps build() {
            return new CfnHostProps() {
                private final java.lang.String $availabilityZone = java.util.Objects.requireNonNull(_availabilityZone, "availabilityZone is required");
                private final java.lang.String $instanceType = java.util.Objects.requireNonNull(_instanceType, "instanceType is required");
                @javax.annotation.Nullable
                private final java.lang.String $autoPlacement = _autoPlacement;
                @javax.annotation.Nullable
                private final java.lang.String $hostRecovery = _hostRecovery;

                @Override
                public java.lang.String getAvailabilityZone() {
                    return this.$availabilityZone;
                }

                @Override
                public java.lang.String getInstanceType() {
                    return this.$instanceType;
                }

                @Override
                public java.lang.String getAutoPlacement() {
                    return this.$autoPlacement;
                }

                @Override
                public java.lang.String getHostRecovery() {
                    return this.$hostRecovery;
                }

                public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
                    com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
                    com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
                    obj.set("availabilityZone", om.valueToTree(this.getAvailabilityZone()));
                    obj.set("instanceType", om.valueToTree(this.getInstanceType()));
                    if (this.getAutoPlacement() != null) {
                        obj.set("autoPlacement", om.valueToTree(this.getAutoPlacement()));
                    }
                    if (this.getHostRecovery() != null) {
                        obj.set("hostRecovery", om.valueToTree(this.getHostRecovery()));
                    }
                    return obj;
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.ec2.CfnHostProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * `AWS::EC2::Host.AvailabilityZone`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-host.html#cfn-ec2-host-availabilityzone
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public java.lang.String getAvailabilityZone() {
            return this.jsiiGet("availabilityZone", java.lang.String.class);
        }

        /**
         * `AWS::EC2::Host.InstanceType`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-host.html#cfn-ec2-host-instancetype
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public java.lang.String getInstanceType() {
            return this.jsiiGet("instanceType", java.lang.String.class);
        }

        /**
         * `AWS::EC2::Host.AutoPlacement`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-host.html#cfn-ec2-host-autoplacement
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        @javax.annotation.Nullable
        public java.lang.String getAutoPlacement() {
            return this.jsiiGet("autoPlacement", java.lang.String.class);
        }

        /**
         * `AWS::EC2::Host.HostRecovery`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-host.html#cfn-ec2-host-hostrecovery
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        @javax.annotation.Nullable
        public java.lang.String getHostRecovery() {
            return this.jsiiGet("hostRecovery", java.lang.String.class);
        }
    }
}
